@@ -1,5 +1,5 @@
-from indy.error import IndyError, ErrorCode
-from indy.wallet import create_wallet, open_wallet
+from vdrtools.error import IndyError, ErrorCode
+from vdrtools.wallet import create_wallet, open_wallet
 
 
 async def create_and_open_wallet(wallet_config, wallet_credentials):
